#ifdef GL_ES
precision lowp float;
#endif

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;
varying vec2 v_normalCoord;

uniform vec2  u_contentSize;
uniform sampler2D u_normalMap;
//uniform sampler2D CC_Texture0;

uniform vec3  u_lightPosInLocalSpace;
uniform vec4  u_lightInfo;
uniform vec4 u_overlayColor;

void main()
{
    vec4 albedo = v_fragmentColor * texture2D(CC_Texture0, v_texCoord);
	vec3 totalLight = vec3(0.9, 0.9, 0.9);
	
	if(u_lightInfo. w != 0.0)
	{
		vec3 normal = texture2D(u_normalMap, v_normalCoord).rgb;
		normal = normal * 2.0 - 1.0; //translating normal map colour to vector values
		normal.y = -normal.y;
		normal=normalize(normal);

		//position of this fragment in world coordinates
		vec3 curPos = vec3(v_normalCoord.x*u_contentSize.x,v_normalCoord.y*u_contentSize.y,0.0);

		
		vec3 lightVec = curPos-u_lightPosInLocalSpace;
		vec3 posToLight= -normalize(lightVec);
		float normDotPosToLight=max(0.0,dot(normal,posToLight));

		vec3 diffuse = normDotPosToLight*u_lightInfo.xyz;
			
		float lightDist = length(lightVec);

		float brightMod = 1.0;
		if(lightDist > 125.0)
		{
			brightMod = 1.0 + (0.05 * (lightDist-125.0));
		}
		float brightness = (u_lightInfo.w / brightMod);
		totalLight = diffuse * brightness + totalLight;
	}
	
	vec4 modifedColour = vec4(u_overlayColor.a) * u_overlayColor + vec4(1.0 - u_overlayColor.a) * (albedo*vec4(totalLight, 1.0)); 
	gl_FragColor.xyz = modifedColour.xyz;
	gl_FragColor.w = albedo.w;
}


